import os
import csv
import glob
import argparse
import matplotlib.pyplot as plt
import numpy as np
from matplotlib.animation import FuncAnimation

def read_csv(file_path):
    with open(file_path, 'r') as file:
        reader = csv.DictReader(file)
        positions = [(float(row['x']), float(row['y']), float(row['z'])) for row in reader]
    return np.array(positions)

def update(frame):
    ax.clear()
    # Adjust these limits based on your simulation
    ax.set_xlim([-2, 2])  
    ax.set_ylim([-2, 2])  
    ax.set_zlim([-2, 2])  
    ax.set_xlabel('X')
    ax.set_ylabel('Y')
    ax.set_zlabel('Z')
    ax.set_title(f'Iteration {frame}')

    try:
        positions = read_csv(f'{folder}/iteration_{frame}.csv')
        ax.scatter(positions[:, 0], positions[:, 1], positions[:, 2], marker='o')
    except FileNotFoundError:
        print(f'CSV file for iteration {frame} not found.')

parser = argparse.ArgumentParser(description='Create a 3D animation from CSV files.')
parser.add_argument('folder', type=str, help='Folder name containing CSV files')

args = parser.parse_args()

folder = args.folder

csv_files = glob.glob(f'{folder}/iteration_*.csv')

num_frames = len(csv_files)

fig = plt.figure()
ax = fig.add_subplot(111, projection='3d')

animation = FuncAnimation(fig, update, frames=num_frames, interval=100, repeat=False)  

animation.save(f'{folder}_simulation.gif', writer='pillow')

plt.show()
